#!/bin/sh
# Petit script pour afficher une image et les température dans QtLockscreen
#
#	Auteur: GaRy delaMer
#
#	Remarques:
#		- le chemins des images:
#			Ligne 31: png1 l'image de yahooweather
#			Ligne 33: png2 l'image à ajouter à QtLockscreen.ini setion weather exemple:
#				[Main]
#				....
#				Widgets\xx\Name="Image.Weather"
#				[Weather]
#				Image="/home/user/apps/QtLockscreen/Weather.png"
#				SizeP="250;180"
#				SizeL="250;180"
#				PosL="0;0"
#				PosP="0;0"
#		- Le script permet de télécharger la page web de yahoo et l'image: 
#			Ligne 35: 1 télécharge, 0 ne télécharge pas
#			Ligne 42: l'url de la page web, visister http://weather.yahoo.com
#		- Traduire les textes et l'unité:
#			Ligne 55: l'unité "°C"
#			Ligne 57: Température maximum
#			Ligne 58: Température minimum
#		- La création de l'image avec imagemagic:
#			Ligne 62 et suivantes: on peut changer la fonte, couleurs (texte et ombre)
# La page web téléchargée
html='/home/user/.queen_beecon_dir/ywtemp.htm'
# L'image de QBW yahooWeather
png1='/home/user/.queen_beecon_dir/ywtemp.png'
# L'image dans QtLockscreen
png2='/home/user/apps/QtLockscreen/Weather.png'

Download=1
if [ "`/sbin/route | awk '/au/ {print $1}'`" != "default" ]; then
	Download=0
	echo 'Pas de connection !!!'
fi
if [ $Download == 1 ]; then
	# télécharge la page web pour analyse
	wget --user-agent='' -q -t 1 -T 10 -O $html 'http://weather.yahoo.com/france/languedoc-roussillon/montpellier-612977/?unit=c'
	# télécharge l'image
	wget --user-agent='' -q -t 1 -T 10 -O $png1 `grep 'forecast-icon.*http.*png' $html | grep -o http*[a-zA-Z0-9\\.\\-\\\\_/\\:]*.png | grep -m 1 http`
fi

# Lire les températures et les modifier
if [ -f $html ]; then
	Temp=`grep 'forecast-icon.*http.*png' $html | grep -o yw-temp..[-0-9]\\* | grep -o temp..[-0-9]* | grep -o [-0-9][-0-9]*`
	High=`grep 'forecast-icon.*http.*png' $html | grep -o High[:].[-0-9][-0-9]* | grep -o [-0-9][-0-9]*`
	Low=`grep 'forecast-icon.*http.*png' $html  | grep -o Low[:].[-0-9][-0-9]* | grep -o [-0-9][-0-9]*`
fi

# Definir le texte et l'unité
unit='°C'
[ $Temp ] && Temp=$Temp$unit
[ $High ] && High='Max: '$High$unit
[ $Low ]  && Low='Min: '$Low$unit

# Créer l'image avec le fond de yahooWeathe et le texte
refresh=0
if [ -f $png1 ]; then
	refresh=1
	convert -font '/home/user/.fonts/tabitha.ttf' \
			-pointsize 34   -weight Bold \
			-draw "text 160,35 '$Temp'" -stroke none -fill 'rgba(255,255,255,1.0)' \
			-draw "text 160,35 '$Temp'" -stroke 'rgba(0,0,0,0.8)' -strokewidth 2 \
			-pointsize 16   -weight Normal \
			-draw "text 160,55 '$High'" -stroke none -fill 'rgba(255,255,255,0.8)' \
			-draw "text 160,55 '$High'" -stroke 'rgba(0,0,0,0.8)' -strokewidth 2 \
			-draw "text 160,75 '$Low'"  -stroke none -fill 'rgba(255,255,255,0.8)' \
			-draw "text 160,75 '$Low'"  -stroke 'rgba(0,0,0,0.8)' -strokewidth 2 \
			$png1 $png2
fi

#Relance QtLockscreen pour appliquer les changements
#echo "PID Before:$(pidof qtlockscreen)"
[ $refresh == 1 ] && pkill -HUP qtlockscreen
#echo "PID After:$(pidof qtlockscreen)"
#Test si le PID de QtLockscreen est vide et Relance QtLockscreen
[ -z "$(pidof QtLockscreen)" -a $refresh == 1 ] && qtlockscreen &
#echo "PID Final:$(pidof qtlockscreen)"
exit 0